#!/bin/bash

# Written by Min-Su Shin

# North = up / East = left
# SDSS_name is from http://skyview.gsfc.nasa.gov/cgi-bin/survey.pl
# objid is a string.
# ra & dec in deg.
# deg_size in deg.
# pix_size is an odd integer.

convert_path="/usr/bin/convert"
montage_path="/usr/bin/montage"
pix_size=501
center_pix=251
circle_pix=261
#SDSS_name="SDSS+r"
#SDSS_name="SDSS+g"
#SDSS_name="SDSS+u"
SDSS_name="SDSS+i"
#SDSS_name="SDSS+z"
# if you want to leave fits files
#leave_fits="1"
leave_fits="0"

if [ $# == 4 ]
then
	objid=$1
	ra=$2
	dec=$3
	deg_size=$4

	echo "Finding chart : "$objid
	rm -f temp.fits temp1.jpg temp2.jpg
	wget "http://skyview.gsfc.nasa.gov/cgi-bin/images?Position=$ra,$dec&Survey=SDSS+r&Coordinates=J2000&Return=FITS&Size=$deg_size&Pixels=$pix_size" -O temp.fits >& /dev/null
	ds9 -width $pix_size -height $pix_size -cmap b -histequ temp.fits -zoom to fit -saveimage jpeg temp1.jpg -exit
	if [ $leave_fits == "1" ]
	then
		cp temp.fits $objid".fits"
	fi
	$convert_path temp1.jpg -contrast -stroke green -strokewidth 4 -fill none \
	-draw "circle $center_pix,$center_pix $circle_pix,$circle_pix" temp2.jpg
	$montage_path -geometry +0+0 -background Yellow -font helvetica -label "$objid" temp2.jpg $objid".jpg"
	rm -f temp.fits temp1.jpg temp2.jpg
else
	echo "usage : ./findingchart_sdss_skyview.sh objid ra(deg) dec(deg) size(deg)"
fi
